StoreMapping

Struct StoreMapping 

pub struct StoreMapping<CreateOp>(/* private fields */);
The StoreMapping adapter obtains a Derivative value by calling the CreateOp (which should take the Original value and return a Derivative one), and returns Some(SaveMappingTo(DERIVATIVE_VALUE)), indicating that the mapping should be saved.

This adapter can be used when the types of the Original and the Derivative differ and can’t be computed from one another.